@@ -23,7 +23,7 @@ Commands:
   usage
   tree
   script
-  intervals
+  spark
   copy
   diff
 
@@ -90,7 +90,8 @@ Options:
     --end=<time>             start and end times (see details below)
     --selection=all|autowindow|givenwindow  downsample method [default: all]
     --format=csv|raw         output format [default: csv]
-    --timeformat=unix|human  unix timestamp or human-readable? [default: human]
+    --timeformat=unix|human|iso8601
+                             unix timestamp or human-readable? [default: human]
     --chunkhours=<hours>     break read into multiple requests of length
                              <hours>, printing data as it is received and
                              ignoring --limit. Note that this requires start
@@ -215,8 +216,8 @@ Options:
                    is used to identify the script, too.
     --recursive    operate on client and any children
     --create       create the script if it doesn't already exist''',
-    'intervals': '''Show distribution of intervals between points.\n\nUsage:
-    exo [options] intervals <cik> [<rid>] --days=<days>
+    'spark': '''Show distribution of intervals between points.\n\nUsage:
+    exo [options] spark <cik> [<rid>] --days=<days>
 
 Options:
     --stddev=<num>  exclude intervals more than num standard deviations from mean
@@ -265,9 +266,17 @@ for k in cmd_doc:
 class ExoException(Exception):
     pass
 
+
 class RPCException(Exception):
     pass
 
+
+class ExolineOnepV1(onep.OnepV1):
+    '''Subclass that re-adds deprecated commands used by Portals'''
+    def comment(self, cik, rid, visibility, comment, defer=False):
+        return self._call('comment', cik, [rid, visibility, comment], defer)
+
+
 class ExoRPC():
     '''Wrapper for pyonep RPC API.
     Raises exceptions on error and provides some reasonable defaults.'''
@@ -280,7 +289,7 @@ class ExoRPC():
 
         if port is None:
             port = DEFAULT_PORT_HTTPS if https else DEFAULT_PORT
-        self.exo = onep.OnepV1(host=host,
+        self.exo = ExolineOnepV1(host=host,
                                port=port,
                                httptimeout=httptimeout,
                                https=https)
@@ -316,6 +325,8 @@ class ExoRPC():
             return []
         assert(not self.exo.has_deferred(cik))
         for c in commands:
+            if type(c) is not list:
+                raise Exception("_exomult: found invalid command")
             method = getattr(self.exo, c[0])
             #print c
             method(cik, *c[1:], defer=True)
@@ -841,11 +852,10 @@ class ExoRPC():
                 for cik in ciks:
                     def up(cik):
                         rid = self._lookup_rid_by_name(cik, name)
-                        print("create: {0}".format(create))
                         if rid is not None or create:
                             self._upload_script(cik, name, text, rid=rid)
                         else:
-                            print("Skipping CIK: {0} -- script named {1} not found".format(cik, name))
+                            print("Skipping CIK: {0} -- {1} not found (--create will create it)".format(cik, name))
 
                     if recursive:
                         self.cik_recursive(cik, up)
@@ -887,8 +897,12 @@ class ExoRPC():
 
     def _create_from_infotree(self, parentcik, infotree):
         '''Create a copy of infotree under parentcik'''
-        typ = infotree['info']['basic']['type']
-        rid = self.create(parentcik, typ, infotree['info']['description'])
+        info_to_copy = infotree['info']
+        typ = info_to_copy['basic']['type']
+        rid = self.create(parentcik, typ, info_to_copy['description'])
+        if 'comments' in info_to_copy and len(info_to_copy['comments']) > 0:
+            commands = [['comment', rid, c[0], c[1]] for c in info_to_copy['comments']]
+            self._exomult(parentcik, commands)
         if typ == 'client':
             # look up new CIK
             cik = self.info(parentcik, rid)['key']
@@ -1319,8 +1333,11 @@ def read_cmd(er, cik, rids, args):
         else:
             if timeformat == 'unix':
                 dt = timestamp
+            elif timeformat == 'iso8601':
+                dt = datetime.isoformat(datetime.fromtimestamp(timestamp))
             else:
                 dt = datetime.fromtimestamp(timestamp)
+
             row = {'timestamp': str(dt)}
             values = dict([(str(rids[i]), val[i]) for i in range(len(rids))])
             row.update(values)
@@ -1384,12 +1401,48 @@ def pretty_print(arg):
 
 def handle_args(cmd, args):
     er = ExoRPC(host=args['--host'], port=args['--port'], https=args['--https'], httptimeout=args["--httptimeout"])
+
+    regex_rid = re.compile("[0-9a-zA-Z]{40}")
     cik = args['<cik>']
 
+    def cik_or_shortcut(cik):
+        '''Look up what was passed for <cik> in config
+           if it doesn't look like a CIK.'''
+        if regex_rid.match(cik) is None:
+            # if cik doesn't look like a cik, maybe it's a shortcut
+            configfile = os.path.join(os.environ['HOME'], '.exoline')
+            try:
+                import yaml
+                with open(configfile) as f:
+                    config = yaml.safe_load(f)
+                    if 'keys' in config:
+                        if cik in config['keys']:
+                            return config['keys'][cik].strip()
+                        else:
+                            raise ExoException('No CIK shortcut {0}\n{1}'.format(
+                                cik,
+                                '\n'.join(config['keys'])))
+                    else:
+                        raise ExoException('Tried a CIK shortcut {0}, but found no keys in {1}'.format(
+                            cik,
+                            configfile))
+            except IOError as ex:
+                raise ExoException(
+                    'Tried a CIK shortcut {0}, but couldn\'t open {1}'.format(
+                    cik,
+                    configfile))
+        else:
+            return cik
+
+    if type(cik) is list:
+        cik = [cik_or_shortcut(c) for c in cik]
+    else:
+        cik = cik_or_shortcut(cik)
+
     def rid_or_alias(rid):
         '''Translate what was passed for <rid> to an alias object if
            it doesn't look like a RID.'''
-        if re.match("[0-9a-zA-Z]{40}", rid) is None:
+        if regex_rid.match(rid) is None:
             return {"alias": rid}
         else:
             return rid
@@ -1572,7 +1625,7 @@ def handle_args(cmd, args):
                          name=args['--name'],
                          recursive=args['--recursive'],
                          create=args['--create'])
-    elif cmd == 'intervals':
+    elif cmd == 'spark':
         days = int(args['--days'])
         end = time.mktime(datetime.now().timetuple())
         start = time.mktime((datetime.now() - timedelta(days=days)).timetuple())
